# flask-school
flask extension with new-school-sdk, 一个正方教务系统的Flask扩展

本项目是基于`school-sdk`的一个`Flask`扩展，封装了常用的方法.

## License

This project is licensed under the MIT License (see the
`LICENSE` file for details).
